import os
from distutils.core import setup

version = '0.1.1'

setup(
    name="django-colorfield",
    version=version,
    keywords=["django", "color"],
    author='Jared Forsyth',
    author_email='jared@jaredforsyth.com',
    license='MIT',
    long_description="A small app providing a colorpicker field for django",
    description="A small app providing a colorpicker field for django",
    classifiers=[
        "License :: OSI Approved :: MIT License",
    ],
    packages=['colorfield'],
    install_requires=['django>=1.2'],
    requires=['django (>=1.2)'],
)




#!/usr/bin/env python

import re

from django import forms
from django.db import models
from django.conf import settings
from django.core.validators import RegexValidator
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _

color_re = re.compile('^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$')
validate_color = RegexValidator(color_re, _(u'Enter a valid color.'), 'invalid')

class ColorWidget(forms.Widget):
    class Media:
        js = [settings.MEDIA_URL + 'colorfield/jscolor.js']
        
    def render(self, name, value, attrs=None):
        return render_to_string('colorfield/color.html', locals())
        
class ColorField(models.CharField):
    default_validators = [validate_color]

    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = 10
        super(ColorField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        kwargs['widget'] = ColorWidget
        return super(ColorField, self).formfield(**kwargs)

# vim: et sw=4 sts=4
